@@ -2,7 +2,8 @@ from .renumbers import re_num_list
 from .renumberscales import re_number_scale_list
 from .redate import re_date_list
 from .reid import re_id_list
-from .reoov import format_word, vi_dict
+from .reabb import list_word_abb
+from .reoov import format_word, check_oov_word
 import re
 from nltk import word_tokenize
 import nltk
@@ -62,7 +63,7 @@ def extract_word_tag(txt, txt_tag):
 
 
 def tagging(txt, debug=False):
-    txt = ' '.join(word_tokenize(txt))
+    txt = ' '.join(word_tokenize(txt)).replace('``', '"')
     txt_tag = ['O'] * len(txt)
 
     # number
@@ -137,22 +138,46 @@ def tagging(txt, debug=False):
         else:
             if len(chars) > 0:
                 word = ''.join(chars)
-                # check oov
-                if format_word(word) not in vi_dict:
+                if format_word(word) in list_word_abb:
                     oov_words.append(word)
                     if list(set(txt_tag[word_idx:word_idx + len(chars)])) == ['O']:
-                        txt_tag[word_idx] = 'B-oov'
+                        txt_tag[word_idx] = 'B-abbrev'
                         for i in range(word_idx + 1, word_idx + len(chars)):
-                            txt_tag[i] = 'I-oov'
+                            txt_tag[i] = 'I-abbrev'
+                else:
+                    # check oov
+                    if check_oov_word(word):
+                        oov_words.append(word)
+                        if list(set(txt_tag[word_idx:word_idx + len(chars)])) == ['O']:
+                            txt_tag[word_idx] = 'B-oov'
+                            for i in range(word_idx + 1, word_idx + len(chars)):
+                                txt_tag[i] = 'I-oov'
             chars = []
             word_idx = idx + 1
+    if len(chars) > 0:
+        word = ''.join(chars)
+        if format_word(word) in list_word_abb:
+            oov_words.append(word)
+            if list(set(txt_tag[word_idx:word_idx + len(chars)])) == ['O']:
+                txt_tag[word_idx] = 'B-abbrev'
+                for i in range(word_idx + 1, word_idx + len(chars)):
+                    txt_tag[i] = 'I-abbrev'
+        else:
+            # check oov
+            if check_oov_word(word):
+                oov_words.append(word)
+                if list(set(txt_tag[word_idx:word_idx + len(chars)])) == ['O']:
+                    txt_tag[word_idx] = 'B-oov'
+                    for i in range(word_idx + 1, word_idx + len(chars)):
+                        txt_tag[i] = 'I-oov'
+
     if debug:
         print(oov_words)
     return extract_word_tag(txt, txt_tag)
 
 
 if __name__ == "__main__":
-    input_text = 'Hiện nay 02/2020 cả nước có 1 208 trường hợp dương tính với virus cúm A/H1N1, trong đó miền Nam dẫn đầu với 182 trường hợp.'
+    input_text = 'nguyễn thị minh khai tp.hcm ĐT: 84 - 8 39302053'
     # input_text = ' '.join(word_tokenize(input_text))
     print(input_text)
     tags = tagging(input_text)
