@@ -1,6 +1,6 @@
 re_num_list = [
     "\d{1,7}",
-    "\d{1,7}[\.,]\d{1,7}",
+    "\d{1,7}[\.,-]\d{1,7}",
     "\d{1,3}[\.,]\d{3}[\.,]\d{1,5}",
     "\d{1,3}[\.,]\d{3}[\.,]\d{1,3}[\.,]\d{1,5}",
 ]
\ No newline at end of file
